@@ -3,6 +3,7 @@
 #endif
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include <gtk/gtk.h>
@@ -57,7 +58,7 @@ on_main_window_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data)
 {
-  gtk_exit (0);
+  exit (0);
 
   /* Shouldn't reach here, but we add it to stop compiler warnings. */
   return FALSE;
@@ -405,16 +406,29 @@ void
 on_About_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  GtkWidget *about;
-  GtkWidget *main_window;
+  static GtkWidget *about = NULL;
 
-  main_window = lookup_widget (GTK_WIDGET (menuitem), "main_window");
+  if (about == NULL) 
+    {
+      GtkWidget *main_window;
 
-  about = create_about_dialog ();
-  /* Make sure the dialog doesn't disappear behind the main window. */
-  gtk_window_set_transient_for (GTK_WINDOW (about), 
-				GTK_WINDOW (main_window));
-  gtk_widget_show (about);
+      about = create_about_dialog ();
+      /* set the widget pointer to NULL when the widget is destroyed */
+      g_signal_connect (G_OBJECT (about),
+			"destroy",
+			G_CALLBACK (gtk_widget_destroyed),
+			&about);
+
+      main_window = lookup_widget (GTK_WIDGET (menuitem), "main_window");
+      /* Make sure the dialog doesn't disappear behind the main window. */
+      gtk_window_set_transient_for (GTK_WINDOW (about), 
+				    GTK_WINDOW (main_window));
+      /* Do not allow user to resize the dialog */
+      gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
+    }
+
+  /* Make sure the dialog is visible. */
+  gtk_window_present (GTK_WINDOW (about));
 }
 
 
