@@ -19,10 +19,6 @@
 #include <string.h>
 
 #include <gdk/gdkkeysyms.h>
-#ifndef _WIN32
-#include <gdk/gdkx.h>
-#endif
-
 #include <gtk/gtk.h>
 
 #include "gladeconfig.h"
@@ -1124,7 +1120,14 @@ editor_on_button_press (GtkWidget * signal_widget,
       else
         {
          static gboolean already_shown = FALSE;
-         if (!already_shown)
+         if (already_shown) 
+           {
+             /* Beep if user does mistake of invalid positioning from second
+              * time.
+              */
+             gdk_beep ();	
+           }
+         else
            {
              glade_util_show_message_box (_("You can't add a widget at the selected position.\n"
 					    "\n"
@@ -2789,15 +2792,8 @@ clear_child_windows (GdkWindow * window, gint x, gint y, gint w, gint h)
   GList *children, *orig_children;
   GdkWindow *child_window;
   gint win_x, win_y, win_w, win_h;
-#ifndef _WIN32
-  XWindowAttributes xwa;
-#endif
   GdkRectangle area, child, intersection;
 
-#ifdef _WIN32
-  return;
-#endif
-
   area.x = x;
   area.y = y;
   area.width = w;
@@ -2819,12 +2815,8 @@ clear_child_windows (GdkWindow * window, gint x, gint y, gint w, gint h)
 	{
 	  /* We need to make sure this is not an InputOnly window, or we get
 	     a BadMatch. CList uses InputOnly windows - for resizing columns.
-	     FIXME: This may not be very efficient. */
-#ifndef _WIN32
-	  XGetWindowAttributes (GDK_DISPLAY (),
-				GDK_WINDOW_XWINDOW (child_window),
-				&xwa);
-	  if (xwa.class != InputOnly)
+	  */
+	  if (! GDK_WINDOW_OBJECT(child_window)->input_only)
 	    {
 	      /* Convert to the child's coordinate space. */
 	      intersection.x -= child.x;
@@ -2836,7 +2828,6 @@ clear_child_windows (GdkWindow * window, gint x, gint y, gint w, gint h)
 				   intersection.x, intersection.y,
 				   intersection.width, intersection.height);
 	    }
-#endif
 	}
       children = children->next;
     }
@@ -3217,6 +3208,11 @@ editor_delete_widget (GtkWidget * widget)
       return;
     }
 
+  /* If we are deleting a GtkTextView set the text to "". This avoids an odd
+     crash. See bug #111604. */
+  if (GTK_IS_TEXT_VIEW (widget))
+    gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)), "", 0);
+
   /* Set properties widget to NULL, in case the widget or parent is deleted */
   property_set_widget (NULL);
 
