@@ -1042,12 +1042,13 @@ gb_button_toolbar_write_source (GtkWidget * widget,
 	{
 	  source_add (data,
 		      "  %s = gtk_toolbar_insert_stock (GTK_TOOLBAR (%s),\n"
-		      "                                %s,\n"
-		      "                                %s,\n"
-		      "                                NULL, NULL, NULL, -1);\n",
+		      "                                %s,\n",
 		      data->wname,
 		      parent_name,
-		      source_make_string (stock_id, FALSE),
+		      source_make_string (stock_id, FALSE));
+	  source_add (data,
+		      "                                %s,\n"
+		      "                                NULL, NULL, NULL, -1);\n",
 		      wdata->tooltip ? source_make_string (wdata->tooltip, data->use_gettext) : "NULL");
 
 	  g_free (parent_name);
