@@ -117,6 +117,19 @@ glade_project_options_class_init (GladeProjectOptionsClass * klass)
   object_class->destroy = glade_project_options_destroy;
 }
 
+static void
+set_accessible_description (GtkWidget *widget, const gchar *desc)
+{
+  AtkObject *atk_widget;
+
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  atk_widget = gtk_widget_get_accessible (widget);
+
+  if (desc)
+    atk_object_set_description (atk_widget, desc);
+}
+ 
 
 static void
 glade_project_options_init (GladeProjectOptions * options)
@@ -568,6 +581,8 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_box_pack_start (GTK_BOX (hbox), options->main_header_entry,
 		      TRUE, TRUE, 0);
 
+  set_accessible_description (options->main_source_entry, _("Source file for interface creation functions")); 
+  set_accessible_description (options->main_header_entry, _("Header file for interface creation functions")); 
 
   /* Handler source file. */
   frame = gtk_frame_new (_("Signal Handler & Callback Functions:"));
@@ -612,6 +627,9 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_box_pack_start (GTK_BOX (hbox), options->handler_header_entry,
 		      TRUE, TRUE, 0);
 
+  set_accessible_description (options->handler_source_entry, _("Source file for signal handler and callback functions"));
+  set_accessible_description (options->handler_header_entry, _("Header file for signal handler and callback functions"));
+
   /* Support source file. */
   frame = gtk_frame_new (_("Support Functions:"));
   gtk_widget_show (frame);
@@ -655,6 +673,8 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_box_pack_start (GTK_BOX (hbox), options->support_header_entry,
 		      TRUE, TRUE, 0);
 
+  set_accessible_description (options->support_source_entry, _("Source file for support functions"));
+  set_accessible_description (options->support_header_entry, _("Header file for support functions")); 
 
   /*
    * libglade Options Page.
