@@ -350,7 +350,7 @@ source_begin_interface_and_callbacks_files (GbWidgetWriteSourceData * data,
 					    FILE **callback_c_fp)
 {
   /* Create the interface.h file and output the standard license. */
-  *interface_h_fp = fopen (data->interface_h_filename, "w");
+  *interface_h_fp = glade_util_fopen (data->interface_h_filename, "w");
   if (*interface_h_fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -365,7 +365,7 @@ source_begin_interface_and_callbacks_files (GbWidgetWriteSourceData * data,
 
   /* Create the interface.c file and output the standard license and #include
      lines. */
-  *interface_c_fp = fopen (data->interface_c_filename, "w");
+  *interface_c_fp = glade_util_fopen (data->interface_c_filename, "w");
   if (*interface_c_fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -383,7 +383,7 @@ source_begin_interface_and_callbacks_files (GbWidgetWriteSourceData * data,
      them for appending. */
   if (data->creating_callback_files)
     {
-      *callback_h_fp = fopen (data->callback_h_filename, "w");
+      *callback_h_fp = glade_util_fopen (data->callback_h_filename, "w");
       if (*callback_h_fp == NULL)
 	{
 	  data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -396,7 +396,7 @@ source_begin_interface_and_callbacks_files (GbWidgetWriteSourceData * data,
 	return;
 
 
-      *callback_c_fp = fopen (data->callback_c_filename, "w");
+      *callback_c_fp = glade_util_fopen (data->callback_c_filename, "w");
       if (*callback_c_fp == NULL)
 	{
 	  data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -410,7 +410,7 @@ source_begin_interface_and_callbacks_files (GbWidgetWriteSourceData * data,
     }
   else
     {
-      *callback_h_fp = fopen (data->callback_h_filename, "a");
+      *callback_h_fp = glade_util_fopen (data->callback_h_filename, "a");
       if (*callback_h_fp == NULL)
 	{
 	  data->error = glade_error_new_system (_("Couldn't append to file:\n  %s\n"),
@@ -418,7 +418,7 @@ source_begin_interface_and_callbacks_files (GbWidgetWriteSourceData * data,
 	  return;
 	}
 
-      *callback_c_fp = fopen (data->callback_c_filename, "a");
+      *callback_c_fp = glade_util_fopen (data->callback_c_filename, "a");
       if (*callback_c_fp == NULL)
 	{
 	  data->error = glade_error_new_system (_("Couldn't append to file:\n  %s\n"),
@@ -807,7 +807,7 @@ source_write_main_c (GbWidgetWriteSourceData * data)
       return;
     }
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1035,7 +1035,7 @@ source_write_gtk_configure_in (GbWidgetWriteSourceData * data)
 
   g_free (alt_filename);
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1126,7 +1126,7 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
       return;
     }
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1320,7 +1320,7 @@ source_write_gnome_configure_in (GbWidgetWriteSourceData * data)
 
   g_free (alt_filename);
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1415,7 +1415,7 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
       return;
     }
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1633,7 +1633,7 @@ source_write_toplevel_makefile_am (GbWidgetWriteSourceData * data)
       return;
     }
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1706,7 +1706,7 @@ source_create_file_if_not_exist (const gchar *directory,
 
   if (!glade_util_file_exists (pathname))
     {
-      fp = fopen (pathname, "w");
+      fp = glade_util_fopen (pathname, "w");
       if (fp)
 	{
 	  if (contents)
@@ -1774,7 +1774,7 @@ source_write_po_files (GbWidgetWriteSourceData * data)
       return;
     }
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1837,7 +1837,7 @@ source_write_acconfig_h (GbWidgetWriteSourceData * data)
       return;
     }
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1883,7 +1883,7 @@ source_write_support_files (GbWidgetWriteSourceData * data)
   /* Create the support header file first. */
   filename = glade_util_make_absolute_path (glade_project_get_source_directory (data->project), glade_project_get_support_header_file (data->project));
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -1999,7 +1999,7 @@ source_write_support_files (GbWidgetWriteSourceData * data)
   /* Now create the support source file. */
   filename = glade_util_make_absolute_path (glade_project_get_source_directory (data->project), glade_project_get_support_source_file (data->project));
 
-  fp = fopen (filename, "w");
+  fp = glade_util_fopen (filename, "w");
   if (fp == NULL)
     {
       data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
@@ -2037,7 +2037,7 @@ source_write_support_files (GbWidgetWriteSourceData * data)
 	       "      else\n"
 	       "        parent = widget->parent;\n"
 	       "      if (!parent)\n"
-	       "        parent = g_object_get_data (G_OBJECT (widget), \"GladeParentKey\");\n"
+	       "        parent = (GtkWidget*) g_object_get_data (G_OBJECT (widget), \"GladeParentKey\");\n"
 	       "      if (parent == NULL)\n"
 	       "        break;\n"
 	       "      widget = parent;\n"
