@@ -24,6 +24,7 @@
 #ifdef _WIN32
 #include <ctype.h>
 #include <direct.h>
+#include <dirent.h>
 #else
 #include <unistd.h>
 #include <dirent.h>
@@ -359,6 +360,7 @@ glade_util_spin_button_new (GtkObject *dialog,
   spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate,
 				    digits);
   g_return_val_if_fail (spinbutton != NULL, NULL);
+  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton), TRUE);
   
   /* save pointer to entry so we can find it easily in the OK handler */
   gtk_object_set_data (GTK_OBJECT (dialog), key, spinbutton);
@@ -1660,8 +1662,12 @@ glade_util_get_next_free_project_directory (gchar **project_directory_return,
   gint project_num, max_project_num, project_string_len;
   gint num_matched, chars_matched;
 
+#ifdef _WIN32
+  projects_dir = "C:\\Projects";
+#else
   projects_dir = glade_util_make_absolute_path (g_get_home_dir (),
 						_("Projects"));
+#endif
 
   /* Step through the 'Projects' directory, if it exists, to find
      subdirectories named 'projectXX', and get the highest number used so
